import requests

base_url = "https://api-beta.codegpt.co/api/v1/"

class Completion:
    def __init__(self, api_key):
        self.api_key = api_key


    def create(self, agent_id, messages, stream=False):
            # Define los valores de headers, messages y la neueva URL
            headers = {
                "Content-Type": "application/json",
                "media_type": "text/event-stream",
                "Authorization": f"Bearer {self.api_key}"
            }

            json = {
                "agent": agent_id,
                "messages": messages,
                "stream": stream,
            }
           
            url = f"{base_url}/chat/completions"

            if stream is False:
                try:
                    response = requests.post(url, json=json, headers=headers)
                    if response.status_code != 200:
                        error_message = f"API Response was: {response.status_code} {response.reason}"
                        raise Exception(error_message)
                    

                    return response.json().split('data: ')[1]
                
                except Exception as e:
                    print(f"An error occurred: {e}")
            else:
                try:
                    response = requests.post(url, json=json, headers=headers)
                    if response.status_code != 200:
                        error_message = f"API Response was: {response.status_code} {response.reason}"
                        raise Exception(error_message)

                    return response.text.split('data: ')
                
                except Exception as e:
                    print(f"An error occurred: {e}")



import requests

base_url = "https://api-beta.codegpt.co/api/v1"

class Document:
    def __init__(self, api_key):
        self.api_key = api_key


    def getAll(self):
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.api_key}"
        }

        url = f"{base_url}/document"

        try:
            response = requests.get(url, headers=headers)
            if response.status_code != 200:
                error_message = f"API Response was: {response.status_code} {response.reason} {url_documentation}"
                raise Exception(error_message)
            else:
                return response.json()

        except Exception as e:
            print(f"An error occurred: {e}")

    def getDocumentById(self,documentId):
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.api_key}"
        }

        url = f"{base_url}/document/"+documentId

        try:
            response = requests.get(url, headers=headers)
            if response.status_code != 200:
                error_message = f"API Response was: {response.status_code} {response.reason} {url_documentation}"
                raise Exception(error_message)
            else:
                return response.json()

        except Exception as e:
            print(f"An error occurred: {e}")
    
    def delete(self,documentId):
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.api_key}"
        }

        url = f"{base_url}/document/"+documentId

        try:
            response = requests.delete(url, headers=headers)
            if response.status_code != 200:
                error_message = f"API Response was: {response.status_code} {response.reason} {url_documentation}"
                raise Exception(error_message)
            else:
                return response.json()

        except Exception as e:
            print(f"An error occurred: {e}")

    def load(self,file):
        headers = {
            "Authorization": f"Bearer {self.api_key}"
        }

        url = f"{base_url}/document/load"

        try:
            with open(file, "rb") as f:
                response = requests.post(url,files={"file" : f},headers=headers)
            if response.status_code != 200:
                error_message = f"API Response was: {response.status_code} {response} {url_documentation}"
                raise Exception(error_message)
            else:
                return response.json()

        except Exception as e:
            print(f"An error occurred: {e}")


    def training(self,documentId):
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.api_key}"
        }

        url = f"{base_url}/document/training/{documentId}"

        try:
            response = requests.post(url, headers=headers)
            if response.status_code != 200:
                error_message = f"API Response was: {response.status_code} {response.reason} {url_documentation}"
                raise Exception(error_message)
            else:
                return response.json()

        except Exception as e:
            print(f"An error occurred: {e}")



    def loadAndTraining(self,file):
        headers = {
            "Authorization": f"Bearer {self.api_key}"
        }

        url = f"{base_url}/document/load-and-training"

        try:
            with open(file, "rb") as f:
                response = requests.post(url, files={"file" : f},headers=headers)

            if response.status_code != 200:
                error_message = f"API Response was: {response.status_code} {response} {url_documentation}"
                raise Exception(error_message)
            else:
                return response.json()

        except Exception as e:
            print(f"An error occurred: {e}")


import requests

base_url = "https://api-beta.codegpt.co/api/v1/"

class CodeGPT:
    def __init__(self, api_key):
        self.api_key = api_key


    def me(self):
        try:
            headers = {
                "Content-Type": "application/json",
                "Authorization": f"Bearer {self.api_key}"
            }

            url = base_url + "/user"
            response = requests.get(url, headers=headers)
            if response.status_code != 200:
                error_message = f"API Response was: {response.status_code} {response.reason}"
                raise Exception(error_message)
            else:
                return response.json()

        except Exception as e:
            print(f"An error occurred: {e}")






import requests

base_url = "https://api-beta.codegpt.co/api/v1/"

class Agent:
    def __init__(self, api_key):
        self.api_key = api_key


    def getAll(self):
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.api_key}"
        }

        url = f"{base_url}/agent"

        try:
            response = requests.get(url, headers=headers)
            if response.status_code != 200:
                error_message = f"API Response: {response.status_code} {response.reason}"
                raise Exception(error_message)
            else:
                return response.json()

        except Exception as e:
            print(f"An error occurred: {e}")
    
    def getAgentById(self,agent_id):
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.api_key}"
        }

        url = f"{base_url}/agent/{agent_id}"

        try:
            response = requests.get(url, headers=headers)
            if response.status_code != 200:
                error_message = f"API CODEGPT Response: {response.status_code} {response.reason}"
                raise Exception(error_message)
            else:
                return response.json()

        except Exception as e:
            print(f"An error occurred: {e}")

    def update(self,agent_id, data):
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.api_key}"
        }
        url = f"{base_url}/agent/{agent_id}"
        try:
            response = requests.patch(url, json=data, headers=headers)
            if response.status_code != 200:
                error_message = f"API Response was: {response.status_code} {response.reason}"
                raise Exception(error_message)
            else:
                return response.json()

        except Exception as e:
            print(f"An error occurred: {e}")    